<?php

/**
 * This file contains the \QUI\Controls\Buttons\Button
 */

namespace QUI\Controls\Buttons;

use QUI;
use QUI\Controls\Contextmenu\MenuItem;
use QUI\Controls\Toolbar\Bar;
use QUI\QDOM;

/**
 * QUI Button
 *
 * @author  www.pcsg.de (Henning Leutz)
 */
class Button extends QDOM
{
    /**
     * The Parent
     *
     * @var ?Bar
     */
    private ?Bar $Parent = null;

    /**
     * Sub Items
     *
     * @var array
     */
    private array $items = [];

    /**
     * Disable status
     *
     * @var bool
     */
    private bool $disabled = false;

    /**
     * constructor
     *
     * @param array $settings
     */
    public function __construct(array $settings = [])
    {
        $this->setAttribute('type', 'QUI\\Controls\\Buttons\\Button');
        $this->setAttributes($settings);
    }

    /**
     * set the parent to the button
     *
     * @param Bar $Parent
     */
    public function setParent(Bar $Parent): void
    {
        $this->Parent = $Parent;
    }

    /**
     * Get the name attribute
     *
     * @return string
     */
    public function getName(): string
    {
        return $this->getAttribute('name');
    }

    /**
     * disable the button
     */
    public function setDisable(): void
    {
        $this->disabled = true;
    }

    /**
     * Add a context item to the button
     *
     * @param MenuItem $item
     */
    public function appendChild(MenuItem $item): void
    {
        $this->items[] = $item;
    }

    /**
     * Return the window as an array
     *
     * @return array
     */
    public function toArray(): array
    {
        $result = $this->getAttributes();
        $result['items'] = [];

        foreach ($this->items as $Itm) {
            try {
                /* @var $Itm MenuItem */
                $Itm->setParent($this);

                $result['items'][] = $Itm->toArray();
            } catch (QUI\Exception $Exception) {
                QUI\System\Log::writeException($Exception);
            }
        }

        return $result;
    }
}
