<?php

/**
 * This file contains the \QUI\Controls\Contextmenu\BarItem
 */

namespace QUI\Controls\Contextmenu;

use QUI\QDOM;

/**
 * ContextBarItem
 *
 * @author  www.pcsg.de (Henning Leutz)
 */
class BarItem extends QDOM
{
    /**
     * subitems
     *
     * @var array
     */
    private array $items = [];

    /**
     * Parent Object
     *
     * @var ?Bar
     */
    private ?Bar $Parent = null;

    /**
     * Constructor
     *
     * @param array $settings
     */
    public function __construct(array $settings)
    {
        $this->setAttributes($settings);
        $this->setAttribute('type', 'qui/controls/contextmenu/BarItem');
    }

    /**
     * Set the parent
     *
     * @param Bar $parent
     */
    public function setParent(Bar $parent): void
    {
        $this->Parent = $parent;
    }

    /**
     * Returns the name
     *
     * @return string
     */
    public function getName(): string
    {
        return $this->getAttribute('name');
    }

    /**
     * Remove all children
     */
    public function clear(): void
    {
        $this->items = [];
    }

    /**
     * Add a child / item
     *
     * @param MenuItem $itm
     */
    public function appendChild(MenuItem $itm): void
    {
        $this->items[] = $itm;
    }

    /**
     * Remove a child item
     *
     * @param string $name - Name of the child
     */
    public function removeChild(string $name): void
    {
        $items = [];

        foreach ($this->items as $Item) {
            if ($name != $Item->getName()) {
                $items[] = $Item;
            }
        }

        $this->items = $items;
    }

    /**
     * Returns a specific child / item
     *
     * @param string $name - Name of the child / item
     *
     * @return bool|MenuItem
     */
    public function getElementByName(string $name): bool|MenuItem
    {
        foreach ($this->items as $itm) {
            if ($name == $itm->getName()) {
                return $itm;
            }
        }

        return false;
    }

    /**
     * Parse to array
     *
     * @return array
     */
    public function toArray(): array
    {
        $result = $this->getAttributes();
        $result['items'] = [];

        foreach ($this->items as $Itm) {
            $Itm->setParent($this);
            $result['items'][] = $Itm->toArray();
        }

        return $result;
    }
}
