<?php

/**
 * This file contains the \QUI\Controls\Toolbar\Bar
 */

namespace QUI\Controls\Toolbar;

use QUI\Controls\Buttons\Button;
use QUI\Controls\Buttons\Separator;
use QUI\Controls\Sitemap\Item;
use QUI\QDOM;

/**
 * Toolbar Bar
 *
 * @author  www.pcsg.de (Henning Leutz)
 */
class Bar
{
    /**
     * all settings from the toolbar
     *
     * @var array
     */
    protected array $settings = [];

    /**
     * all subitems from the toolbar
     *
     * @var array
     */
    protected array $items = [];

    /**
     * constructor
     *
     * @param array $settings
     */
    public function __construct(array $settings)
    {
        $this->settings = $settings;
    }

    /**
     * Adds a child / item
     *
     * @param Button|Item|Separator|Tab $itm
     */
    public function appendChild(Button|Item|Tab|Separator $itm): void
    {
        $this->items[] = $itm;
    }

    /**
     * Returns the name
     *
     * @return string
     */
    public function getName(): string
    {
        return $this->settings['name'];
    }

    /**
     * Removes all items/children
     */
    public function clear(): void
    {
        $this->items = [];
    }

    /**
     * Returns all items / children
     *
     * @return array
     */
    public function getItems(): array
    {
        return $this->items;
    }

    /**
     * Returns a specific item
     *
     * @param string $name - name of the item
     * @return bool|Item|Tab|Button|Separator
     */
    public function getElementByName(string $name): Button|Item|bool|Tab|Separator
    {
        foreach ($this->items as $itm) {
            if ($itm->getName() == $name) {
                return $itm;
            }
        }

        return false;
    }

    /**
     * Removes a specific item / child
     *
     * @param QDOM $Child - Child
     */
    public function removeChild(QDOM $Child): void
    {
        foreach ($this->items as $key => $Itm) {
            if ($Itm == $Child) {
                unset($this->items[$key]);
            }
        }
    }

    /**
     * Returns the first item / child
     *
     * @return QDOM|false
     */
    public function firstChild(): bool|QDOM
    {
        if (!isset($this->items[0])) {
            return false;
        }

        return $this->items[0];
    }

    /**
     * Returns all children / items
     *
     * @return array
     */
    public function getChildren(): array
    {
        return $this->items;
    }

    /**
     * Parse to array
     *
     * @return array
     */
    public function toArray(): array
    {
        $result = [];

        foreach ($this->items as $Itm) {
            $result[] = $Itm->getAttributes();
        }

        return $result;
    }
}
